@@ -10,8 +10,8 @@ import publication
 from jsii.python import classproperty
 
 import aws_cdk.aws_iam
-import aws_cdk.cdk
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.35.0", __name__, "aws-kms@0.35.0.jsii.tgz")
+import aws_cdk.core
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.36.0", __name__, "aws-kms@0.36.0.jsii.tgz")
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[])
 class AliasAttributes(jsii.compat.TypedDict):
     """
@@ -37,7 +37,7 @@ class AliasProps(jsii.compat.TypedDict):
     Stability:
         experimental
     """
-    name: str
+    aliasName: str
     """The name of the alias.
 
     The name must start with alias followed by a
@@ -59,25 +59,25 @@ class AliasProps(jsii.compat.TypedDict):
         experimental
     """
 
-class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnAlias"):
+class CfnAlias(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnAlias"):
     """A CloudFormation ``AWS::KMS::Alias``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html
     Stability:
-        experimental
+        stable
     cloudformationResource:
         AWS::KMS::Alias
     """
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, alias_name: str, target_key_id: str) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, alias_name: str, target_key_id: str) -> None:
         """Create a new ``AWS::KMS::Alias``.
 
         Arguments:
             scope: - scope in which this resource is defined.
             id: - scoped id of the resource.
             props: - resource properties.
-            aliasName: ``AWS::KMS::Alias.AliasName``.
-            targetKeyId: ``AWS::KMS::Alias.TargetKeyId``.
+            alias_name: ``AWS::KMS::Alias.AliasName``.
+            target_key_id: ``AWS::KMS::Alias.TargetKeyId``.
 
         Stability:
             experimental
@@ -93,26 +93,26 @@ class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
             props: -
 
         Stability:
-            experimental
+            stable
         """
         return jsii.invoke(self, "renderProperties", [props])
 
     @classproperty
-    @jsii.member(jsii_name="cfnResourceTypeName")
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> str:
         """The CloudFormation resource type name for this resource class.
 
         Stability:
-            experimental
+            stable
         """
-        return jsii.sget(cls, "cfnResourceTypeName")
+        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
     @property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         """
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "cfnProperties")
 
@@ -124,7 +124,7 @@ class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-aliasname
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "aliasName")
 
@@ -140,7 +140,7 @@ class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-targetkeyid
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "targetKeyId")
 
@@ -156,7 +156,7 @@ class CfnAliasProps(jsii.compat.TypedDict):
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html
     Stability:
-        experimental
+        stable
     """
     aliasName: str
     """``AWS::KMS::Alias.AliasName``.
@@ -164,7 +164,7 @@ class CfnAliasProps(jsii.compat.TypedDict):
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-aliasname
     Stability:
-        experimental
+        stable
     """
 
     targetKeyId: str
@@ -173,32 +173,32 @@ class CfnAliasProps(jsii.compat.TypedDict):
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-targetkeyid
     Stability:
-        experimental
+        stable
     """
 
-class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnKey"):
+class CfnKey(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnKey"):
     """A CloudFormation ``AWS::KMS::Key``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html
     Stability:
-        experimental
+        stable
     cloudformationResource:
         AWS::KMS::Key
     """
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, key_policy: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.IResolvable], description: typing.Optional[str]=None, enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]=None, enable_key_rotation: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]=None, key_usage: typing.Optional[str]=None, pending_window_in_days: typing.Optional[jsii.Number]=None, tags: typing.Optional[typing.List[aws_cdk.cdk.CfnTag]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, key_policy: typing.Any, description: typing.Optional[str]=None, enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, enable_key_rotation: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, key_usage: typing.Optional[str]=None, pending_window_in_days: typing.Optional[jsii.Number]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None) -> None:
         """Create a new ``AWS::KMS::Key``.
 
         Arguments:
             scope: - scope in which this resource is defined.
             id: - scoped id of the resource.
             props: - resource properties.
-            keyPolicy: ``AWS::KMS::Key.KeyPolicy``.
+            key_policy: ``AWS::KMS::Key.KeyPolicy``.
             description: ``AWS::KMS::Key.Description``.
             enabled: ``AWS::KMS::Key.Enabled``.
-            enableKeyRotation: ``AWS::KMS::Key.EnableKeyRotation``.
-            keyUsage: ``AWS::KMS::Key.KeyUsage``.
-            pendingWindowInDays: ``AWS::KMS::Key.PendingWindowInDays``.
+            enable_key_rotation: ``AWS::KMS::Key.EnableKeyRotation``.
+            key_usage: ``AWS::KMS::Key.KeyUsage``.
+            pending_window_in_days: ``AWS::KMS::Key.PendingWindowInDays``.
             tags: ``AWS::KMS::Key.Tags``.
 
         Stability:
@@ -233,26 +233,26 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
             props: -
 
         Stability:
-            experimental
+            stable
         """
         return jsii.invoke(self, "renderProperties", [props])
 
     @classproperty
-    @jsii.member(jsii_name="cfnResourceTypeName")
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> str:
         """The CloudFormation resource type name for this resource class.
 
         Stability:
-            experimental
+            stable
         """
-        return jsii.sget(cls, "cfnResourceTypeName")
+        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
     @property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> str:
         """
         Stability:
-            experimental
+            stable
         cloudformationAttribute:
             Arn
         """
@@ -263,36 +263,36 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
     def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
         """
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "cfnProperties")
 
     @property
     @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.cdk.TagManager:
+    def tags(self) -> aws_cdk.core.TagManager:
         """``AWS::KMS::Key.Tags``.
 
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-tags
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "tags")
 
     @property
     @jsii.member(jsii_name="keyPolicy")
-    def key_policy(self) -> typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.IResolvable]:
+    def key_policy(self) -> typing.Any:
         """``AWS::KMS::Key.KeyPolicy``.
 
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keypolicy
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "keyPolicy")
 
     @key_policy.setter
-    def key_policy(self, value: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.IResolvable]):
+    def key_policy(self, value: typing.Any):
         return jsii.set(self, "keyPolicy", value)
 
     @property
@@ -303,7 +303,7 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-description
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "description")
 
@@ -313,34 +313,34 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
 
     @property
     @jsii.member(jsii_name="enabled")
-    def enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]:
+    def enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
         """``AWS::KMS::Key.Enabled``.
 
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enabled
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "enabled")
 
     @enabled.setter
-    def enabled(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]):
+    def enabled(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
         return jsii.set(self, "enabled", value)
 
     @property
     @jsii.member(jsii_name="enableKeyRotation")
-    def enable_key_rotation(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]:
+    def enable_key_rotation(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
         """``AWS::KMS::Key.EnableKeyRotation``.
 
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enablekeyrotation
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "enableKeyRotation")
 
     @enable_key_rotation.setter
-    def enable_key_rotation(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.cdk.IResolvable]]]):
+    def enable_key_rotation(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
         return jsii.set(self, "enableKeyRotation", value)
 
     @property
@@ -351,7 +351,7 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keyusage
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "keyUsage")
 
@@ -367,7 +367,7 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
         See:
             http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-pendingwindowindays
         Stability:
-            experimental
+            stable
         """
         return jsii.get(self, "pendingWindowInDays")
 
@@ -384,23 +384,23 @@ class _CfnKeyProps(jsii.compat.TypedDict, total=False):
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-description
     Stability:
-        experimental
+        stable
     """
-    enabled: typing.Union[bool, aws_cdk.cdk.IResolvable]
+    enabled: typing.Union[bool, aws_cdk.core.IResolvable]
     """``AWS::KMS::Key.Enabled``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enabled
     Stability:
-        experimental
+        stable
     """
-    enableKeyRotation: typing.Union[bool, aws_cdk.cdk.IResolvable]
+    enableKeyRotation: typing.Union[bool, aws_cdk.core.IResolvable]
     """``AWS::KMS::Key.EnableKeyRotation``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enablekeyrotation
     Stability:
-        experimental
+        stable
     """
     keyUsage: str
     """``AWS::KMS::Key.KeyUsage``.
@@ -408,7 +408,7 @@ class _CfnKeyProps(jsii.compat.TypedDict, total=False):
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keyusage
     Stability:
-        experimental
+        stable
     """
     pendingWindowInDays: jsii.Number
     """``AWS::KMS::Key.PendingWindowInDays``.
@@ -416,15 +416,15 @@ class _CfnKeyProps(jsii.compat.TypedDict, total=False):
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-pendingwindowindays
     Stability:
-        experimental
+        stable
     """
-    tags: typing.List[aws_cdk.cdk.CfnTag]
+    tags: typing.List[aws_cdk.core.CfnTag]
     """``AWS::KMS::Key.Tags``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-tags
     Stability:
-        experimental
+        stable
     """
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.CfnKeyProps", jsii_struct_bases=[_CfnKeyProps])
@@ -434,19 +434,19 @@ class CfnKeyProps(_CfnKeyProps):
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html
     Stability:
-        experimental
+        stable
     """
-    keyPolicy: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.IResolvable]
+    keyPolicy: typing.Any
     """``AWS::KMS::Key.KeyPolicy``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keypolicy
     Stability:
-        experimental
+        stable
     """
 
 @jsii.interface(jsii_type="@aws-cdk/aws-kms.IAlias")
-class IAlias(aws_cdk.cdk.IResource, jsii.compat.Protocol):
+class IAlias(aws_cdk.core.IResource, jsii.compat.Protocol):
     """A KMS Key alias.
 
     Stability:
@@ -481,7 +481,7 @@ class IAlias(aws_cdk.cdk.IResource, jsii.compat.Protocol):
         ...
 
 
-class _IAliasProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
+class _IAliasProxy(jsii.proxy_for(aws_cdk.core.IResource)):
     """A KMS Key alias.
 
     Stability:
@@ -514,7 +514,7 @@ class _IAliasProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
 
 
 @jsii.implements(IAlias)
-class Alias(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Alias"):
+class Alias(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Alias"):
     """Defines a display name for a customer master key (CMK) in AWS Key Management Service (AWS KMS).
 
     Using an alias to refer to a key can help you simplify key
@@ -529,32 +529,32 @@ class Alias(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/a
     resource:
         AWS::KMS::Alias
     """
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, name: str, target_key: "IKey") -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, alias_name: str, target_key: "IKey") -> None:
         """
         Arguments:
             scope: -
             id: -
             props: -
-            name: The name of the alias. The name must start with alias followed by a forward slash, such as alias/. You can't specify aliases that begin with alias/AWS. These aliases are reserved.
-            targetKey: The ID of the key for which you are creating the alias. Specify the key's globally unique identifier or Amazon Resource Name (ARN). You can't specify another alias.
+            alias_name: The name of the alias. The name must start with alias followed by a forward slash, such as alias/. You can't specify aliases that begin with alias/AWS. These aliases are reserved.
+            target_key: The ID of the key for which you are creating the alias. Specify the key's globally unique identifier or Amazon Resource Name (ARN). You can't specify another alias.
 
         Stability:
             experimental
         """
-        props: AliasProps = {"name": name, "targetKey": target_key}
+        props: AliasProps = {"aliasName": alias_name, "targetKey": target_key}
 
         jsii.create(Alias, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromAliasAttributes")
     @classmethod
-    def from_alias_attributes(cls, scope: aws_cdk.cdk.Construct, id: str, *, alias_name: str, alias_target_key: "IKey") -> "IAlias":
+    def from_alias_attributes(cls, scope: aws_cdk.core.Construct, id: str, *, alias_name: str, alias_target_key: "IKey") -> "IAlias":
         """
         Arguments:
             scope: -
             id: -
             attrs: -
-            aliasName: 
-            aliasTargetKey: 
+            alias_name: 
+            alias_target_key: 
 
         Stability:
             experimental
@@ -585,7 +585,7 @@ class Alias(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/a
 
 
 @jsii.interface(jsii_type="@aws-cdk/aws-kms.IKey")
-class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
+class IKey(aws_cdk.core.IResource, jsii.compat.Protocol):
     """A KMS Key, either managed by this CDK app, or imported.
 
     Stability:
@@ -625,7 +625,7 @@ class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
 
         Arguments:
             statement: The policy statement to add.
-            allowNoOp: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
+            allow_no_op: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
 
         Stability:
             experimental
@@ -682,7 +682,7 @@ class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
         ...
 
 
-class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
+class _IKeyProxy(jsii.proxy_for(aws_cdk.core.IResource)):
     """A KMS Key, either managed by this CDK app, or imported.
 
     Stability:
@@ -719,7 +719,7 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
 
         Arguments:
             statement: The policy statement to add.
-            allowNoOp: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
+            allow_no_op: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
 
         Stability:
             experimental
@@ -777,7 +777,7 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
 
 
 @jsii.implements(IKey)
-class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Key"):
+class Key(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Key"):
     """Defines a KMS key.
 
     Stability:
@@ -785,7 +785,7 @@ class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws
     resource:
         AWS::KMS::Key
     """
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, removal_policy: typing.Optional[aws_cdk.cdk.RemovalPolicy]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy]=None) -> None:
         """
         Arguments:
             scope: -
@@ -793,9 +793,9 @@ class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws
             props: -
             description: A description of the key. Use a description that helps your users decide whether the key is appropriate for a particular task. Default: - No description.
             enabled: Indicates whether the key is available for use. Default: - Key is enabled.
-            enableKeyRotation: Indicates whether AWS KMS rotates the key. Default: false
+            enable_key_rotation: Indicates whether AWS KMS rotates the key. Default: false
             policy: Custom policy document to attach to the KMS key. Default: - A policy document with permissions for the account root to administer the key will be created.
-            removalPolicy: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: RemovalPolicy.Retain
+            removal_policy: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: RemovalPolicy.Retain
 
         Stability:
             experimental
@@ -821,13 +821,13 @@ class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws
 
     @jsii.member(jsii_name="fromKeyArn")
     @classmethod
-    def from_key_arn(cls, scope: aws_cdk.cdk.Construct, id: str, key_arn: str) -> "IKey":
+    def from_key_arn(cls, scope: aws_cdk.core.Construct, id: str, key_arn: str) -> "IKey":
         """Import an externally defined KMS Key using its ARN.
 
         Arguments:
             scope: the construct that will "own" the imported key.
             id: the id of the imported key in the construct tree.
-            keyArn: the ARN of an existing KMS key.
+            key_arn: the ARN of an existing KMS key.
 
         Stability:
             experimental
@@ -852,7 +852,7 @@ class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws
 
         Arguments:
             statement: The policy statement to add.
-            allowNoOp: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
+            allow_no_op: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
 
         Stability:
             experimental
@@ -987,7 +987,7 @@ class KeyProps(jsii.compat.TypedDict, total=False):
         experimental
     """
 
-    removalPolicy: aws_cdk.cdk.RemovalPolicy
+    removalPolicy: aws_cdk.core.RemovalPolicy
     """Whether the encryption key should be retained when it is removed from the Stack.
 
     This is useful when one wants to
@@ -1009,8 +1009,8 @@ class ViaServicePrincipal(aws_cdk.aws_iam.PrincipalBase, metaclass=jsii.JSIIMeta
     def __init__(self, service_name: str, base_principal: typing.Optional[aws_cdk.aws_iam.IPrincipal]=None) -> None:
         """
         Arguments:
-            serviceName: -
-            basePrincipal: -
+            service_name: -
+            base_principal: -
 
         Stability:
             experimental
